==> qdapDictionaries_0.0.3.tar.gz: qdapDictionaries/README.md <==
# qdapDictionaries
[![Build Status](https://travis-ci.org/trinker/qdapDictionaries.png?branch=master)](https://travis-ci.org/trinker/qdapDictionaries)

![qdapicon](https://dl.dropbox.com/u/61803503/qdapicon.png)   
[qdapDictionaries](http://trinker.github.com/qdapDictionaries/) is an R package containing the dictionaries and word lists for use with the qdap package.

## Installation

To download the development version of qdapDictionaries:

Download the [zip ball](https://github.com/trinker/qdapDictionaries/zipball/master) or [tar ball](https://github.com/trinker/qdapDictionaries/tarball/master), decompress and run `R CMD INSTALL` on it, or use the **devtools** package to install the development version:

```r
# install.packages("devtools")

library(devtools)
install_github("qdapDictionaries", "trinker")
```

**Note**: Windows users need [Rtools](http://www.murdoch-sutherland.com/Rtools/) and [devtools](http://CRAN.R-project.org/package=devtools) to install this way.

**Note**: Mac users might be required to install the appropriate version [XTools](https://developer.apple.com/xcode/) from the [Apple Developer site](https://developer.apple.com/) in order to install the development version.  You may need to [register as an Apple developer](https://developer.apple.com/programs/register/).  An older version of XTools may also be required.



## Help
[Web Page](http://trinker.github.com/qdapDictionaries/)    
[Package PDF Help Manual](https://dl.dropbox.com/u/61803503/qdapDictionaries.pdf)

==> qdapDictionaries_0.0.4.tar.gz: qdapDictionaries/README.md <==
# qdapDictionaries
[![Build Status](https://travis-ci.org/trinker/qdapDictionaries.png?branch=master)](https://travis-ci.org/trinker/qdapDictionaries)

![qdapicon](https://dl.dropbox.com/u/61803503/qdapicon.png)   
[qdapDictionaries](http://trinker.github.com/qdapDictionaries_dev/) is an R package containing the dictionaries and word lists for use with the qdap package.

## Installation

To download the development version of qdapDictionaries:

Download the [zip ball](https://github.com/trinker/qdapDictionaries/zipball/master) or [tar ball](https://github.com/trinker/qdapDictionaries/tarball/master), decompress and run `R CMD INSTALL` on it, or use the **devtools** package to install the development version:

```r
# install.packages("devtools")

library(devtools)
install_github("qdapDictionaries", "trinker")
```

**Note**: Windows users need [Rtools](http://www.murdoch-sutherland.com/Rtools/) and [devtools](http://CRAN.R-project.org/package=devtools) to install this way.

**Note**: Mac users might be required to install the appropriate version [XTools](https://developer.apple.com/xcode/) from the [Apple Developer site](https://developer.apple.com/) in order to install the development version.  You may need to [register as an Apple developer](https://developer.apple.com/programs/register/).  An older version of XTools may also be required.



## Help
[Web Page](http://trinker.github.com/qdapDictionaries/)    
[Package PDF Help Manual](https://dl.dropbox.com/u/61803503/qdapDictionaries.pdf)
